@@ -11,4 +11,4 @@ class mainGame:
         obj_game.print_data()
         obj_game.play
 
-m = mainGame()
\ No newline at end of file
+#m = mainGame()
\ No newline at end of file
